@@ -224,7 +224,7 @@ class InterfaceFileHandling:
         src_blob = BlobClient(
             self.blob_service_client.url,
             container_name=self.settings.storage_container,
-            blob_name=location + "/" + filename,
+            blob_name=filename,
             credential=self.sas_token
         )
 
@@ -245,7 +245,7 @@ class InterfaceFileHandling:
         result, files, file_names = self.list_files(location=location, file_pattern=pattern)
         if result["code"] == "OK":
             for file in files:
-                print("Downloading file >%s<" % file)
+                print("Downloading file >%s< from location >%s<" % (file, location))
                 self.download_file(location=location, filename=file)
         else:
             print("An error occurred listing files", result)
